cgexplore.systems\_optimisation.Generation
==========================================

.. currentmodule:: cgexplore.systems_optimisation

.. autoclass:: Generation
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Generation.calculate_elite_fitness
      ~Generation.calculate_fitness_values
      ~Generation.get_generation_size
      ~Generation.run_structures
      ~Generation.select_all
      ~Generation.select_best
      ~Generation.select_elite
      ~Generation.select_worst
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Generation.chromosomes
      ~Generation.fitness_calculator
      ~Generation.structure_calculator
      ~Generation.num_processes
   
   